StorageError

Enum StorageError 

pub enum StorageError {
    ReadOnly,
    IOError(Arc<Error>),
    InvalidMetadata(StoreKey, String),
    MissingMetadata(StorePrefix),
    StorePrefixError(StorePrefixError),
    InvalidStoreKey(StoreKeyError),
    InvalidByteRangeError(InvalidByteRangeError),
    Unsupported(String),
    UnknownKeySize(StoreKey),
    Other(String),
}
A storage error.

Variants



ReadOnly

A write operation was attempted on a read only store.



IOError(Arc<Error>)

An IO error.



InvalidMetadata(StoreKey, String)

An error parsing the metadata for a key.



MissingMetadata(StorePrefix)

Missing metadata.



StorePrefixError(StorePrefixError)

An invalid store prefix.



InvalidStoreKey(StoreKeyError)

An invalid store key.



InvalidByteRangeError(InvalidByteRangeError)

An invalid byte range.



Unsupported(String)

The requested method is not supported.



UnknownKeySize(StoreKey)

Unknown key size where the key size must be known.



Other(String)

Any other error.